@@ -1,4 +1,4 @@
-#' Convert an ecocomDP dataset to a Darwin Core Archive dataset
+#' Convert a dataset to the Darwin Core Archive format
 #'
 #' @param path (character) Path to which the DwC-A data objects and EML will be written.
 #' @param core_name (character) The central table of the DwC-A dataset being created. Can be: "event" (event core). Occurrence core is not yet supported.
@@ -56,7 +56,7 @@ convert_to_dwca <- function(path,
   # Load data -----------------------------------------------------------------
   
   d <- read_data(source_id)
-  d <- d[[1]]$tables
+  d <- d$tables
   
   # Convert tables ------------------------------------------------------------
   
